@@ -31,6 +31,7 @@
 #include <gpe/gpeclockface.h>
 #include <gpe/schedule.h>
 #include <gpe/launch.h>
+#include <gpe/infoprint.h>
 
 Display *dpy;
 
@@ -353,7 +354,7 @@ set_alarm (struct alarm_state *alarm)
 	  alarm->day = tm.tm_mday;
 	}
 
-      if (schedule_set_alarm (1, t, "gpe-announce\ngpe-clock --check-alarm\n") == FALSE)
+      if (schedule_set_alarm (1, t, "gpe-announce\ngpe-clock --check-alarm\n", FALSE) == FALSE)
 	{
 	  gpe_error_box (_("Unable to set alarm"));
 	  alarm->active = FALSE;
@@ -616,6 +617,8 @@ alarm_window (void)
   if (alarm_window_open)
     return;
 
+  alarm_window_open = TRUE;
+
   time_label = gtk_label_new (_("Time:"));
 
   spacing = gpe_get_boxspacing ();
@@ -921,6 +924,10 @@ main (int argc, char *argv[])
 
   g_timeout_add (1000, (GtkFunction) update_time, NULL);
 
+  XSelectInput (dpy, DefaultRootWindow (dpy), PropertyChangeMask);
+  gpe_launch_install_filter ();
+  gpe_launch_monitor_display (dpy);
+
   gtk_main ();
 
   exit (0);
